import { ApplySchemaAttributes, CommandFunction, MarkExtension, MarkExtensionSpec, MarkSpecOverride, PrimitiveSelection, Static } from '@remirror/core';
import { Palette } from '@remirror/extension-text-color';
/**
 * Add a highlight color to the selected text (or text within a specified
 * range).
 */
export declare class TextHighlightExtension extends MarkExtension<TextHighlightOptions> {
    get name(): "textHighlight";
    createTags(): ("formattingMark" | "fontStyle")[];
    createMarkSpec(extra: ApplySchemaAttributes, override: MarkSpecOverride): MarkExtensionSpec;
    /**
     * Set the text highlight color value for the selected text.
     */
    setTextHighlight(highlight: string, options?: HighlightCommandOptions): CommandFunction;
    /**
     * Remove the highlight mark from the selection.
     */
    removeTextHighlight(options?: HighlightCommandOptions): CommandFunction;
}
export interface TextHighlightOptions {
    /**
     * The default highlight value.
     *
     * @default ''
     */
    defaultHighlight?: Static<string>;
    /**
     * The color palette which is a function that returns a list of colors and
     * labels for help with ui. It is completely optional and you are free to use
     * use whatever colors you choose.
     */
    palette?: Palette;
}
export interface TextHighlightAttributes {
    /**
     * The highlight color.
     *
     * @default ''
     */
    highlight?: string;
}
interface HighlightCommandOptions {
    selection?: PrimitiveSelection;
}
declare global {
    namespace Remirror {
        interface AllExtensions {
            textHighlight: TextHighlightExtension;
        }
    }
}
export {};
