'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _objectWithoutProperties = require('@babel/runtime/helpers/objectWithoutProperties');
var _objectSpread = require('@babel/runtime/helpers/objectSpread2');
var _applyDecoratedDescriptor = require('@babel/runtime/helpers/applyDecoratedDescriptor');
var core = require('@remirror/core');
var extensionTextColor = require('@remirror/extension-text-color');
var messages = require('@remirror/messages');

var _excluded = ["highlight"];

var _dec, _dec2, _dec3, _class, _class2;
var setTextHighlightOptions = {
  icon: 'markPenLine',
  description: _ref => {
    var t = _ref.t;
    return t(messages.ExtensionTextHighlightMessages.DESCRIPTION);
  },
  label: _ref2 => {
    var t = _ref2.t;
    return t(messages.ExtensionTextHighlightMessages.LABEL);
  }
};
var TEXT_HIGHLIGHT_ATTRIBUTE = 'data-text-highlight-mark';
/**
 * Add a highlight color to the selected text (or text within a specified
 * range).
 */

var TextHighlightExtension = (_dec = core.extension({
  defaultOptions: {
    defaultHighlight: '',
    palette: extensionTextColor.palette
  },
  staticKeys: ['defaultHighlight']
}), _dec2 = core.command(setTextHighlightOptions), _dec3 = core.command(), _dec(_class = (_class2 = class TextHighlightExtension extends core.MarkExtension {
  get name() {
    return 'textHighlight';
  }

  createTags() {
    return [core.ExtensionTag.FormattingMark, core.ExtensionTag.FontStyle];
  }

  createMarkSpec(extra, override) {
    var _override$parseDOM;

    return _objectSpread(_objectSpread({}, override), {}, {
      attrs: _objectSpread(_objectSpread({}, extra.defaults()), {}, {
        highlight: {
          default: this.options.defaultHighlight
        }
      }),
      parseDOM: [{
        tag: "span[".concat(TEXT_HIGHLIGHT_ATTRIBUTE, "]"),
        getAttrs: dom => {
          if (!core.isElementDomNode(dom)) {
            return;
          }

          var highlight = dom.getAttribute(TEXT_HIGHLIGHT_ATTRIBUTE);

          if (!highlight) {
            return;
          }

          return _objectSpread(_objectSpread({}, extra.parse(dom)), {}, {
            highlight
          });
        }
      }, {
        tag: "span[".concat(TEXT_HIGHLIGHT_ATTRIBUTE, "]"),
        getAttrs: dom => {
          if (!core.isElementDomNode(dom)) {
            return;
          }

          var highlight = dom.getAttribute(TEXT_HIGHLIGHT_ATTRIBUTE);

          if (!highlight) {
            return;
          }

          return _objectSpread(_objectSpread({}, extra.parse(dom)), {}, {
            highlight
          });
        }
      }, {
        // Get the color from the css style property. This is useful for pasted content.
        style: 'background-color',
        priority: core.ExtensionPriority.Low,
        getAttrs: highlight => {
          if (!core.isString(highlight)) {
            return;
          }

          return {
            highlight
          };
        }
      }, ...((_override$parseDOM = override.parseDOM) !== null && _override$parseDOM !== void 0 ? _override$parseDOM : [])],
      toDOM: mark => {
        var _omitExtraAttributes = core.omitExtraAttributes(mark.attrs, extra),
            highlight = _omitExtraAttributes.highlight,
            other = _objectWithoutProperties(_omitExtraAttributes, _excluded);

        var extraAttrs = extra.dom(mark);
        var style = extraAttrs.style;

        if (highlight) {
          style = core.joinStyles({
            backgroundColor: highlight
          }, style);
        }

        return ['mark', _objectSpread(_objectSpread(_objectSpread({}, other), extraAttrs), {}, {
          style,
          [TEXT_HIGHLIGHT_ATTRIBUTE]: highlight
        }), 0];
      }
    });
  }
  /**
   * Set the text highlight color value for the selected text.
   */


  setTextHighlight(highlight, options) {
    return this.store.commands.applyMark.original(this.type, {
      highlight
    }, options === null || options === void 0 ? void 0 : options.selection);
  }
  /**
   * Remove the highlight mark from the selection.
   */


  removeTextHighlight(options) {
    return this.store.commands.removeMark.original(_objectSpread(_objectSpread({
      type: this.type
    }, options), {}, {
      expand: true
    }));
  }

}, (_applyDecoratedDescriptor(_class2.prototype, "setTextHighlight", [_dec2], Object.getOwnPropertyDescriptor(_class2.prototype, "setTextHighlight"), _class2.prototype), _applyDecoratedDescriptor(_class2.prototype, "removeTextHighlight", [_dec3], Object.getOwnPropertyDescriptor(_class2.prototype, "removeTextHighlight"), _class2.prototype)), _class2)) || _class);

exports.TextHighlightExtension = TextHighlightExtension;
